MaximumMeanDiscrepancy - LatentLego

Skip to content

# MaximumMeanDiscrepancy

### `latent.losses.MaximumMeanDiscrepancy`

Computes Maximum Mean Discrepancy (MMD) loss between conditions (`y_true`) in `y_pred`.

#### `__init__(self, n_conditions=2, kernel_method='ms_rbf', **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`n_conditions` | `int` | Positive integer indicating number of conditions. | `2`
`kernel_method` | `str` | Name of kernel method to use. Can be one of the following: `'ms_rbf'` Multi-scale RBF kernel (Lotfollahi 2019) `'rbf'` Basic RBF kernel `'rq'` Rational Quadratic kernel | `'ms_rbf'`
`**kwargs` | `` | Other arguments passed to `keras.losses.Loss`. | `{}`